package com.emato.cus.supervise.biz.acqGoodsMoveSchedule.up;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domain.WmsAcqGoodsMove;
import com.emato.cus.supervise.domainCus.CusAcqGoodsMove05;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.emato.cus.supervise.domainOmsShop.OmsShopAcqGoodsMove;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 门店转移 Oms 门店
 * @author Scott Chen
 * @version 1.0
 * 2020-03-30 11:27
 */
@Component
public class AcqGoodsMoveUpOmsShopDataConversion implements DataConversion {

    private final  static Logger logger = LoggerFactory.getLogger(AcqGoodsMoveUpOmsShopDataConversion.class);

    /**
     * 货物库位移动数据
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("门店转移数据开始转换, 组装cus数据===========================");
        List<OmsShopAcqGoodsMove> omsShopList = (List<OmsShopAcqGoodsMove>) params.get("omsShopList");

        List<CusAcqGoodsMove05> cusAcqGoodsMove05List = Lists.newArrayList();

        for (int i = 0; i < omsShopList.size(); i++) {
            // #20190521001
            // 未作try catch 导致一个sku数据异常，全部终止
            try {
                OmsShopAcqGoodsMove data = omsShopList.get(i);

                String osku = data.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}", osku);
                    continue;
                }
                //logger.debug("当前转换的sku为: {}", osku);

                CusAcqGoodsMove05 cusAcqGoodsMove05 = new CusAcqGoodsMove05();

                cusAcqGoodsMove05.setShelfLoadTime(data.getShelfLoadTime());
                cusAcqGoodsMove05.setShelfUnloadTime(data.getShelfUnloadTime());
                cusAcqGoodsMove05.setTargetSeatNo(data.getTargetSeatNo());
                cusAcqGoodsMove05.setOriginSeatNo(data.getOriginSeatNo());

                cusAcqGoodsMove05.setGoodsName(data.getGoodsName());
                cusAcqGoodsMove05.setCodeTs(data.getCodeTs());
                cusAcqGoodsMove05.setSkuNo(data.getSkuNo());
                cusAcqGoodsMove05.setGoodsId(data.getGoodsId());

                cusAcqGoodsMove05.setgUnit(data.getgUnit());
                cusAcqGoodsMove05.setgQty(data.getgQty());
                cusAcqGoodsMove05.setLegalUnit(data.getLegalUnit());
                cusAcqGoodsMove05.setLegalQty(data.getLegalQty());

                cusAcqGoodsMove05.setGoodsModel(data.getGoodsModel());
                cusAcqGoodsMove05.setLocalEmsNo(data.getLocalEmsNo());

                cusAcqGoodsMove05.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqGoodsMove05.setStoreUscCode(Dict.storeUscCode);
                cusAcqGoodsMove05.setStoreCustomsCode(Dict.storeCustomsCode);
                cusAcqGoodsMove05.setStoreCode(Dict.storeCodeMap.get(data.getStoreCode()));

                cusAcqGoodsMove05.setCreateTime(LocalDateTime.now());
                cusAcqGoodsMove05.setCreaterSn(Dict.operater);
                cusAcqGoodsMove05.setModerSn(Dict.operater);
                cusAcqGoodsMove05.setModTime(LocalDateTime.now());

                cusAcqGoodsMove05List.add(cusAcqGoodsMove05);
            }catch (Exception e){
                logger.error("门店转移数据转换组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("门店转移数据转换, 组装cus数据结束===========================");
        return cusAcqGoodsMove05List;
    }
}
